<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>QEyesConfigDialog</name>
    <message>
        <location filename="../qeyesconfigdialog.cpp" line="44"/>
        <source>Appearance</source>
        <translation>Vormgeving</translation>
    </message>
    <message>
        <location filename="../qeyesconfigdialog.cpp" line="50"/>
        <source>Number of eyes</source>
        <translation>Aantal ogen</translation>
    </message>
    <message>
        <location filename="../qeyesconfigdialog.cpp" line="56"/>
        <source>Type</source>
        <translation>Soort</translation>
    </message>
    <message>
        <location filename="../qeyesconfigdialog.cpp" line="60"/>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <location filename="../qeyesconfigdialog.cpp" line="65"/>
        <source>Reset</source>
        <translation>Standaardwaarden</translation>
    </message>
    <message>
        <location filename="../qeyesconfigdialog.cpp" line="69"/>
        <source>QEyes Settings</source>
        <translation>QEyes-instellingen</translation>
    </message>
    <message>
        <location filename="../qeyesconfigdialog.cpp" line="103"/>
        <source>QEyes default</source>
        <translation>QEyes-standaardwaarden</translation>
    </message>
</context>
</TS>
